@@ -2,7 +2,7 @@ test_that("high level functions working?", {
     embed_methods <- dimRedMethodList(filter = TRUE)
     quality_methods <- dimRedQualityList(filter = TRUE)
     scurve <- loadDataSet("3D S Curve", n = 300)
-    for(i in 1:ncol(scurve@data)){
+    for (i in seq_len(ncol(scurve@data))){
       scurve@data[, i] <- scurve@data[, i] - min(scurve@data[, i])
     }
 
